skills

# XMLRésuméLibrary: User Guide

skillareas | Element Reference | skillset

## Name

skills — Group of one or more skills

Deprecated

## Synopsis

### Content Model

    (skill+)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.4.0. It should not be used.

`skill` elements are now allowed as direct children of `skillset`, so `skills` is no longer necessary. `skills` is still allowed in this release of XML Résumé Library, but may be removed in future versions. It is recommended that you remove all `skills` elements from XML résumés.

The `skills` element contains one or more (usually related) skills.

### Parents

`skills` may be contained in these elements: `skillset`

### Attributes

`id`

  A string used to uniquely identify a skills group. The group may then be referred to by this identifier.

## See Also

`skills.format`.

## Examples

    <skills>
      <skill>Leaping over tall buildings in a single bound</skill>
      <skill>Flying</skill>
      <skill>Quickly changing clothes</skill>
    </skill>

skillareas | Element Reference | skillset